FlutterPopBottomSheet class

A customizable bottom sheet with dismissible behavior.

FlutterPopBottomSheet provides a flexible bottom sheet that can be used to display custom content with a rounded design and optional dismiss behavior.

Example usage:

showModalBottomSheet(
  context: context,
  isScrollControlled: true,
  builder: (context) => FlutterPopBottomSheet(
    content: Text("This is a custom bottom sheet"),
    contentPadding: EdgeInsets.all(16),
    contentMargin: EdgeInsets.all(8),
    barrierDismissible: true,
    backgroundColor: Colors.white,
    borderRadius: 16.0,
  ),
);

Parameters:

Inheritance

Constructors

FlutterPopBottomSheet({Key? key, required Widget content, required EdgeInsets contentPadding, required EdgeInsets contentMargin, required bool barrierDismissible, required Color backgroundColor, required BorderRadius borderRadius})
const

Properties

backgroundColor Color
final
barrierDismissible bool
final
borderRadius BorderRadius
final
content Widget
final
contentMargin EdgeInsets
final
contentPadding EdgeInsets
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited